==> giphy4j-1.0.0-sources.jar: at/mukprojects/giphy4j/exception/GiphyException.java <==
/** 
 * This code is copyright (c) Mathias Markl 2016
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

package at.mukprojects.giphy4j.exception;

/**
 * The GiphyException class is used to throw an exception whenever an error
 * occurred during the process.
 * 
 * @author Mathias Markl
 */
public class GiphyException extends Exception {

    private static final long serialVersionUID = -2564399168708610588L;

    /**
     * Constructs a new exception.
     */
    public GiphyException() {
	super();
    }

    /**
     * Constructs a new exception with the specified detail message and cause.
     * 
     * @param message
     *            The detail message.
     * @param cause
     *            The cause.
     */
    public GiphyException(String message, Throwable cause) {
	super(message, cause);
    }

    /**
     * Constructs a new exception with the specified detail message.
     * 
     * @param message
     *            The detail message.
     */
    public GiphyException(String message) {
	super(message);
    }

    /**
     * Constructs a new exception with the specified cause.
     * 
     * @param cause
     *            The cause.
     */
    public GiphyException(Throwable cause) {
	super(cause);
    }

}

==> giphy4j-1.0.1-sources.jar: at/mukprojects/giphy4j/exception/GiphyException.java <==
/** 
 * This code is copyright (c) Mathias Markl 2016
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

package at.mukprojects.giphy4j.exception;

/**
 * The GiphyException class is used to throw an exception whenever an error
 * occurred during the process.
 * 
 * @author Mathias Markl
 */
public class GiphyException extends Exception {

    private static final long serialVersionUID = -2564399168708610588L;

    /**
     * Constructs a new exception.
     */
    public GiphyException() {
	super();
    }

    /**
     * Constructs a new exception with the specified detail message and cause.
     * 
     * @param message
     *            the detail message
     * @param cause
     *            the cause
     */
    public GiphyException(String message, Throwable cause) {
	super(message, cause);
    }

    /**
     * Constructs a new exception with the specified detail message.
     * 
     * @param message
     *            the detail message
     */
    public GiphyException(String message) {
	super(message);
    }

    /**
     * Constructs a new exception with the specified cause.
     * 
     * @param cause
     *            the cause
     */
    public GiphyException(Throwable cause) {
	super(cause);
    }

}
